@@ -1,8 +1,8 @@
-# @(#)Ident: Base.pm 2013-05-08 10:22 pjf ;
+# @(#)Ident: Base.pm 2013-05-09 18:13 pjf ;
 
 package Module::Provision::Base;
 
-use version; our $VERSION = qv( sprintf '0.12.%d', q$Rev: 3 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.12.%d', q$Rev: 5 $ =~ /\d+/gmx );
 
 use Class::Usul::Moose;
 use Class::Usul::Constants;
@@ -105,6 +105,16 @@ has '_testdir'         => is => 'lazy', isa => Path, coerce => TRUE,
 # Object attributes (private)
 has '_license_keys'    => is => 'lazy', isa => HashRef;
 
+# Public methods
+sub chdir {
+   my ($self, $path) = @_; $path or throw 'Directory not specified in chdir';
+
+   chdir $path; $self->io( getcwd )->stat->{inode} = $path->stat->{inode}
+      or throw error => 'Chdir requested path [_1] actual [_2]',
+               args  => [ $path, getcwd ];
+   return $path;
+}
+
 # Private methods
 sub _build__appbase {
    my $self = shift; my $base = $self->base->absolute( $self->initial_wd );
@@ -113,21 +123,23 @@ sub _build__appbase {
 }
 
 sub _build__appldir {
-   my $self = shift; my $appbase = $self->appbase; my $branch = $self->branch;
+   my $self   = shift; my $appbase = $self->appbase;
 
-   $self->debug and $self->log->debug
-      ( "Appbase: ${appbase}, Branch: ${branch}" );
+   my $branch = $self->branch; my $vcs = $self->vcs;
+
+   $self->debug and $self->warning
+      ( "Appbase: ${appbase}, Branch: ${branch}, VCS: ${vcs}" );
 
    return $appbase->catdir( $branch )->exists ? $appbase->catdir( $branch )
-        : $appbase->catdir( '.git' )->exists  ? $appbase
-        : $self->vcs eq 'none'                ? $appbase
+        : $appbase->catdir( '.git'  )->exists ? $appbase
+        : $appbase->catdir( '.svn'  )->exists ? $appbase
+        : $vcs eq 'none'                      ? $appbase
                                               : undef;
 }
 
 sub _build_branch {
-   my $self = shift;
-
-   return $ENV{BRANCH} || ($self->vcs eq 'svn' ? 'trunk' : 'master');
+   return $ENV{BRANCH} || ($_[ 0 ]->vcs eq 'git' ? 'master' :
+                           $_[ 0 ]->vcs eq 'svn' ? 'trunk'  : 'none');
 }
 
 sub _build_builder {
@@ -182,7 +194,7 @@ sub _build_project {
       $prev = $dir; $dir = $dir->parent;
    }
 
-   throw error => 'File [_1] not in path', args => [ $self->project_file ];
+   throw 'No project files in path';
    return; # Never reached
 }
 
@@ -222,6 +234,9 @@ sub _build_vcs {
    return $appbase->catdir( '.git'            )->exists ? 'git'
         : $appbase->catdir( $branch, '.git'   )->exists ? 'git'
         : $appbase->catdir( qw(master .git)   )->exists ? 'git'
+        : $appbase->catdir( '.svn'            )->exists ? 'svn'
+        : $appbase->catdir( $branch, '.svn'   )->exists ? 'svn'
+        : $appbase->catdir( qw(trunk  .svn)   )->exists ? 'svn'
         : $appbase->catdir( $self->repository )->exists ? 'svn'
                                                         : 'none';
 }
@@ -258,7 +273,7 @@ Module::Provision::Base - Immutable data object
 
 =head1 Version
 
-This documents version v0.12.$Rev: 3 $ of L<Module::Provision::Base>
+This documents version v0.12.$Rev: 5 $ of L<Module::Provision::Base>
 
 =head1 Description
 
